/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_CATEGORY;

import fr.unistra.sil.erp.back.controller.IRetrieveCategoriesController;
import fr.unistra.sil.erp.back.model.Category;

import java.util.List;

import fr.unistra.sil.erp.back.repository.ICategoriesRepository;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * REST controller for the category list.
 *
 * @author BEAUVAIS ANTOINE
 */
@RestController
public class ApiRetrieveCategoriesController implements IRetrieveCategoriesController {

    private final ICategoriesRepository repository;

    /**
     * Class constructor.
     * @param repository the category repository.
     */
    public ApiRetrieveCategoriesController(ICategoriesRepository repository) {
        this.repository = repository;
    }

    /**
     * Returns the list of categories in JSON format.
     *
     * @return the HTTP response.
     * @throws ApiServerErrorException Database failure.
     */
    @GetMapping(MAPPING_CATEGORY)
    @Override
    public ResponseEntity<Object> getCategories() throws ApiServerErrorException {
        List<Category> res = repository.getCategories();
        if (res == null)
            throw new ApiServerErrorException("Database failure.");

        return new ResponseEntity<>(res, HttpStatus.OK);
    }

}
