/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.interceptor.api;

import com.google.gson.Gson;
import fr.unistra.sil.erp.back.model.ErrorMessage;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.servlet.HandlerInterceptor;

/**
 * API Authentication Interceptor.
 * 
 * Each request going through an API call will be processed
 * by this interceptor first.
 * @author BEAUVAIS ANTOINE
 */
public class ApiAuthenticationInterceptor implements HandlerInterceptor {
    
    /**
     * API key.
     */
    private final String apikey;
    
    /**
     * Class constructor.
     * @param string the API key.
     */
    public ApiAuthenticationInterceptor(String string)
    {
        this.apikey = string;
    }
    
    /**
     * Code used to check the request's API key against the real one.
     * @param request the HTTP Servlet request.
     * @param response the HTTP Servlet response.
     * @param handler the handler Object.
     * @return whether the request should be continued.
     */
    @Override
    public boolean preHandle(HttpServletRequest request,
            HttpServletResponse response, Object handler)
    {
        if(request.getMethod().equals("OPTIONS"))
            return true;
        
        if(this.apikey == null)
        {
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
            Gson gson = new Gson();
            ErrorMessage errMsg = new ErrorMessage("Missing API key on server");
            String responseBody = gson.toJson(errMsg);
            
            response.setContentType("application/json");
            response.setCharacterEncoding("UTF-8");
            try {
                PrintWriter printBody = response.getWriter();
                printBody.print(responseBody);
            } catch (IOException ex) {
                Logger.getLogger(ApiAuthenticationInterceptor.class.getName())
                        .log(Level.SEVERE, "Failed to write body.", ex);
            }
            return false;
        }
        
        String login = request.getHeader("apikey");
        if(login == null)
        {
            response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            Gson gson = new Gson();
            ErrorMessage errMsg = new ErrorMessage("Missing API key.");
            String responseBody = gson.toJson(errMsg);
            
            response.setContentType("application/json");
            response.setCharacterEncoding("UTF-8");
            try {
                PrintWriter printBody = response.getWriter();
                printBody.print(responseBody);
            } catch (IOException ex) {
                Logger.getLogger(ApiAuthenticationInterceptor.class.getName())
                        .log(Level.SEVERE, "Failed to write body.", ex);
            }
            return false;
        }
        
        if(! login.equals(this.apikey) )
        {
            response.setStatus(HttpServletResponse.SC_FORBIDDEN);
            Gson gson = new Gson();
            ErrorMessage errMsg = new ErrorMessage("Invalid API key.");
            String responseBody = gson.toJson(errMsg);
            
            response.setContentType("application/json");
            response.setCharacterEncoding("UTF-8");
            try {
                PrintWriter printBody = response.getWriter();
                printBody.print(responseBody);
            } catch (IOException ex) {
                Logger.getLogger(ApiAuthenticationInterceptor.class.getName())
                        .log(Level.SEVERE, "Failed to write body.", ex);
            }
            return false;
        }
        
        return true;
    }
    
}
