/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.model;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Entry in the Registry.
 * 
 * The registry contains all credit and debit operations relative to
 * the operating organization.
 * 
 * @author BEAUVAIS ANTOINE
 */
public class RegistryEntry {
    
    /**
     * The entry's ID.
     */
    private final Integer id;
    
    /**
     * The transaction's type.
     */
    private final int transactionType;

    /**
     * Transaction type name.
     */
    private final String typeName;
    
    /**
     * The date and time for this transaction.
     */
    private final Date dt;

    /**
     * String version of the date.
     *
     * For some reason Thymeleaf cannot parse the Date object.
     */
    private final String dateString;
    
    /**
     * The ID of the associated account.
     */
    private final int accountId;

    /**
     * Account string name.
     */
    private final String account;
    
    /**
     * The amount of money, if it's a debit.
     */
    private final BigDecimal debit;
    
    /**
     * The amount of money, if it's a credit.
     */
    private final BigDecimal credit;
    
    /**
     * Arbitrary remarks. Optional.
     */
    private final String remarks;
    
    /**
     * Class constructor.
     * @param id the entry's ID.
     * @param transactionType transaction type.
     * @param dt the transaction's date.
     * @param accountId the associated account's ID.
     * @param debit
     * @param credit
     * @param remarks arbitrary remarks.
     */
    public RegistryEntry(Integer id, int transactionType, Date dt,
            int accountId, BigDecimal debit, BigDecimal credit,
            String remarks)
    {
        this.id = id;
        this.transactionType = transactionType;
        this.typeName = null;
        this.dt = dt;
        this.dateString = this.dt.toString();
        this.accountId = accountId;
        this.account = null;
        this.debit = debit;
        this.credit = credit;
        this.remarks = remarks;
    }

    public RegistryEntry(Integer id, int transactionType, String tName, Date dt,
            int accountId, String account, BigDecimal debit, BigDecimal credit,
            String remarks)
    {
        this.id = id;
        this.transactionType = transactionType;
        this.typeName = tName;
        this.dt = dt;
        this.dateString = this.dt.toString();
        this.accountId = accountId;
        this.account = account;
        this.debit = debit;
        this.credit = credit;
        this.remarks = remarks;
    }
    
    /**
     * Returns the entry's ID.
     * @return the entry's ID.
     */
    public Integer getId()
    {
        return this.id;
    }
    
    /**
     * Returns the transaction's type.
     * @return the transaction's type.
     */
    public int getTransactionType()
    {
        return this.transactionType;
    }

    /**
     * Returns the transaction type's name.
     * @return the name.
     */
    public String getTypeName()
    {
        return this.typeName;
    }
    
    /**
     * Returns the transaction's date and time.
     * @return the date and time.
     */
    public Date getDatetime()
    {
        return this.dt;
    }

    public String getDateString()
    {
        return this.dateString;
    }
    
    /**
     * Returns the associated account's ID.
     * @return the associated account's ID.
     */
    public int getAccountId()
    {
        return this.accountId;
    }

    public String getAccount()
    {
        return this.account;
    }
    
    /**
     * Returns the debit amount.
     * @return the amount.
     */
    public BigDecimal getDebit()
    {
        return this.debit;
    }
    
    /**
     * Returns the credit amount.
     * @return the amount.
     */
    public BigDecimal getCredit()
    {
        return this.credit;
    }
    
    /**
     * Returns the arbitrary remarks.
     * @return the remarks.
     */
    public String getRemarks()
    {
        return this.remarks;
    }
    
}
