package fr.unistra.sil.erp.back.service;

import fr.unistra.sil.erp.back.controller.api.ApiResourceNotFoundException;
import fr.unistra.sil.erp.back.model.Category;
import fr.unistra.sil.erp.back.model.Item;
import fr.unistra.sil.erp.back.repository.DatabaseResourceNotFoundException;
import fr.unistra.sil.erp.back.repository.ICategoriesRepository;
import fr.unistra.sil.erp.back.repository.IItemsRepository;
import org.springframework.stereotype.Service;

/**
 *
 * @author antoine.beauvais
 */
@Service
public class StoreItemService {
    private final ICategoriesRepository categoriesRepository;
    private final IItemsRepository itemsRepository;

    public StoreItemService( ICategoriesRepository categoriesRepository, IItemsRepository itemsRepository) {
        this.categoriesRepository = categoriesRepository;
        this.itemsRepository = itemsRepository;
    }

    /**
     *
     * @param request
     * @return
     * @throws CantStoreItemException
     */
    public Item store(StoreItemRequest request) throws CantStoreItemException, ApiResourceNotFoundException {
        Category category;
        try {
            category = categoriesRepository.getCategory(request.getCategory());
        } catch (DatabaseResourceNotFoundException e) {
            throw new ApiResourceNotFoundException("Category not found");
        }
        Item stored = itemsRepository.store(new Item(
                null,
                request.getName(),
                request.getPrice(),
                request.getSubscriberPrice(),
                category
        ));
        if (stored == null) {
            throw new CantStoreItemException("Can't store item");
        }
        return stored;
    }
}
